{ config, pkgs, lib, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  services.blueman.enable = true;

  services.tailscale.enable = true;

  boot.loader.efi.canTouchEfiVariables = true;

  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    enableCryptodisk = true;
    device = "nodev";
    useOSProber = true;
  };

  boot.initrd.luks.devices = {
    crypted = {
      device = "/dev/disk/by-uuid/24bc9d4e-fc76-4b70-ba95-8533c416a9d0";
      preLVM = true;
    };
  };

  # Support mounting NTFS partitions
  boot.supportedFilesystems = [ "ntfs" ];

  # audio controls and polybar module don't work on pipewire
  hardware.pulseaudio = {
    enable = true;
    support32Bit = true;
  };
  services.pipewire.enable = lib.mkForce false;

  # https://discourse.nixos.org/t/nixos-rebuild-switch-upgrade-networkmanager-wait-online-service-failure/30746
  systemd.services.NetworkManager-wait-online.enable = lib.mkForce false;
}
